( cd usr/lib ; rm -rf libgr.so.1 )
( cd usr/lib ; ln -sf libgr.so.1.3 libgr.so.1 )
( cd usr/lib ; rm -rf libfbm.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libfbm.sa libfbm.sa )
( cd usr/lib ; rm -rf libjpeg.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libjpeg.sa libjpeg.sa )
( cd usr/lib ; rm -rf libpbm.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpbm.sa libpbm.sa )
( cd usr/lib ; rm -rf libpgm.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpgm.sa libpgm.sa )
( cd usr/lib ; rm -rf libpnm.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpnm.sa libpnm.sa )
( cd usr/lib ; rm -rf libppm.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libppm.sa libppm.sa )
( cd usr/lib ; rm -rf librle.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/librle.sa librle.sa )
( cd usr/lib ; rm -rf libtiff.sa )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libtiff.sa libtiff.sa )
( cd usr/lib ; rm -rf libfbm.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libfbm.a libfbm.a )
( cd usr/lib ; rm -rf libjpeg.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libjpeg.a libjpeg.a )
( cd usr/lib ; rm -rf libpbm.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpbm.a libpbm.a )
( cd usr/lib ; rm -rf libpgm.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpgm.a libpgm.a )
( cd usr/lib ; rm -rf libpnm.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libpnm.a libpnm.a )
( cd usr/lib ; rm -rf libppm.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libppm.a libppm.a )
( cd usr/lib ; rm -rf librle.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/librle.a librle.a )
( cd usr/lib ; rm -rf libtiff.a )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libtiff.a libtiff.a )
( cd usr/lib ; rm -rf libgr.so.1.3 )
( cd usr/lib ; ln -sf /cdrom/usr/lib/libgr.so.1.3 libgr.so.1.3 )
( cd usr ; rm -rf include )
( cd usr ; ln -sf /cdrom/usr/include include )
